import sys
import asyncio
from autobahn.asyncio.wamp import ApplicationSession, ApplicationRunner
from components.monitor import MonitorComponent

def main(args=None):
    
    if args is None:
        args = sys.argv[1:]
    print("tirith monitor 0.2.0")
    print("connecting")
    
    runner = ApplicationRunner(url=u"ws://frameshift:8080/ws", realm=u"realm1")
    runner.run(MonitorComponent)
    
if __name__ == "__main__":
    main()


import sys
import asyncio
from autobahn.asyncio.wamp import ApplicationSession, ApplicationRunner

class TestComponent(ApplicationSession):
    
    async def onJoin(self, details):
        print("session ready")
        
        def add2(x, y):
            return x + y
            
        try:
            await self.register(add2, u"tirith.add2")
            print ("procedure registered")
        except Exception as e:
            print ("could not register procedure: {0}".format(e))
    

def main(args=None):
    if args is None:
        args = sys.argv[1:]    
    print("tirith client 0.2.0")
    
    print ("connecting...")
    
    runner = ApplicationRunner(url=u"ws://frameshift:8080/ws", realm=u"realm1")
    # throws socket.gaierror on 404
    runner.run(TestComponent)
    


if __name__ == "__main__":
    main()


# coding=UTF-8

from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='tirith',
    version='0.2.1',
    description='Monitoring software',
    long_description=long_description,
    url='https://github.com/utfsmlabs/tirith',
    author='René Mujica Moreau',
    author_email='rene.mujica.m@gmail.com',
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 1 - Planning',

        # Indicate who your project is intended for
        'Intended Audience :: System Administrators',
        'Topic :: System :: Monitoring',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.5',
    ],
    keywords='monitoring',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=['autobahn'],
    entry_points={
        'console_scripts': [
            'tirith=tirith.monitor:main',
        ],
    },
)


import asyncio
from autobahn.asyncio.wamp import ApplicationSession

class MonitorComponent(ApplicationSession):
    
    async def onJoin(self, details):
        print("session ready")
        
        def log(thing):
            print(str(thing))
            
        try:
            await self.register(log, u"tirith.log")
            print ("procedure registered")
        except Exception as e:
            print ("could not register procedure: {0}".format(e))